summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEunhae Choi <eunhae1.choi@samsung.com>2016-06-27 17:40:51 +0900
committerEunhae Choi <eunhae1.choi@samsung.com>2016-06-27 17:40:51 +0900
commitc5adb78cc57f8999e023987dd38e718c5fc5a76a (patch)
treed6e2c39553add2041c43280d878c7f4cc572d0a8
parent75178cda606301da423c9ddaf9e869a892f44fe5 (diff)
downloadlibmm-player-c5adb78cc57f8999e023987dd38e718c5fc5a76a.tar.gz
libmm-player-c5adb78cc57f8999e023987dd38e718c5fc5a76a.tar.bz2
libmm-player-c5adb78cc57f8999e023987dd38e718c5fc5a76a.zip
Change-Id: I8b461a29499e62c20f47a57cc343c17224145acd
-rw-r--r--packaging/libmm-player.spec2
-rw-r--r--src/include/mm_player.h4
-rw-r--r--src/include/mm_player_priv.h4
-rw-r--r--src/mm_player.c4
-rw-r--r--src/mm_player_priv.c14
5 files changed, 14 insertions, 14 deletions
diff --git a/packaging/libmm-player.spec b/packaging/libmm-player.spec
index d8d737e..07f012c 100644
--- a/packaging/libmm-player.spec
+++ b/packaging/libmm-player.spec
@@ -1,6 +1,6 @@
Name: libmm-player
Summary: Multimedia Framework Player Library
-Version: 0.5.84
+Version: 0.5.85
Release: 0
Group: Multimedia/Libraries
License: Apache-2.0
diff --git a/src/include/mm_player_priv.h b/src/include/mm_player_priv.h
index c435bdd..8d43d0b 100644
--- a/src/include/mm_player_priv.h
+++ b/src/include/mm_player_priv.h
@@ -518,7 +518,7 @@ typedef struct {
/* streaming player */
mm_player_streaming_t *streamer;
- gchar *http_file_buffer_path;
+ gchar *http_file_buffering_path;
/* gstreamer pipeline */
MMPlayerGstPipelineInfo *pipeline;
@@ -854,7 +854,7 @@ int _mmplayer_set_video_share_master_clock(MMHandleType hplayer, long long clock
int _mmplayer_get_video_share_master_clock(MMHandleType hplayer, long long *video_time, long long *media_clock, long long *audio_time);
int _mmplayer_get_video_rotate_angle(MMHandleType hplayer, int *angle);
int _mmplayer_enable_sync_handler(MMHandleType hplayer, bool enable);
-int _mmplayer_set_temp_file_path(MMHandleType hplayer, const char* file_path);
+int _mmplayer_set_file_buffering_path(MMHandleType hplayer, const char* file_path);
int _mmplayer_set_uri(MMHandleType hplayer, const char* uri);
int _mmplayer_set_next_uri(MMHandleType hplayer, const char* uri, bool is_first_path);
int _mmplayer_get_next_uri(MMHandleType hplayer, char** uri);
diff --git a/src/mm_player.c b/src/mm_player.c
index 258abb9..d243294 100644
--- a/src/mm_player.c
+++ b/src/mm_player.c
@@ -1328,7 +1328,7 @@ int mm_player_release_video_stream_bo(MMHandleType player, void* bo)
return result;
}
-int mm_player_set_temp_file_path(MMHandleType player, const char *file_path)
+int mm_player_set_file_buffering_path(MMHandleType player, const char *file_path)
{
int result = MM_ERROR_NONE;
@@ -1336,7 +1336,7 @@ int mm_player_set_temp_file_path(MMHandleType player, const char *file_path)
MMPLAYER_CMD_LOCK( player );
- result = _mmplayer_set_temp_file_path(player, file_path);
+ result = _mmplayer_set_file_buffering_path(player, file_path);
MMPLAYER_CMD_UNLOCK( player );
diff --git a/src/mm_player_priv.c b/src/mm_player_priv.c
index 6c89ccb..3688d3d 100644
--- a/src/mm_player_priv.c
+++ b/src/mm_player_priv.c
@@ -99,8 +99,8 @@
#define MMPLAYER_USE_FILE_FOR_BUFFERING(player) \
(((player)->profile.uri_type != MM_PLAYER_URI_TYPE_HLS) && \
(player->ini.http_use_file_buffer) && \
- (player->http_file_buffer_path) && \
- (strlen(player->http_file_buffer_path) > 0) )
+ (player->http_file_buffering_path) && \
+ (strlen(player->http_file_buffering_path) > 0) )
#define MM_PLAYER_NAME "mmplayer"
/*---------------------------------------------------------------------------
@@ -11403,7 +11403,7 @@ __mmplayer_try_to_plug_decodebin(mm_player_t* player, GstPad *srcpad, const GstC
1.0, // no meaning
player->ini.http_buffering_limit, // no meaning
type,
- player->http_file_buffer_path,
+ player->http_file_buffering_path,
(guint64)dur_bytes);
}
@@ -12682,7 +12682,7 @@ ERROR:
return;
}
-int _mmplayer_set_temp_file_path(MMHandleType hplayer, const char* file_path)
+int _mmplayer_set_file_buffering_path(MMHandleType hplayer, const char* file_path)
{
int result = MM_ERROR_NONE;
mm_player_t* player = (mm_player_t*) hplayer;
@@ -12691,8 +12691,8 @@ int _mmplayer_set_temp_file_path(MMHandleType hplayer, const char* file_path)
MMPLAYER_RETURN_VAL_IF_FAIL (player, MM_ERROR_PLAYER_NOT_INITIALIZED);
if (file_path) {
- player->http_file_buffer_path = (gchar*)file_path;
- LOGD("temp file path: %s\n", player->http_file_buffer_path);
+ player->http_file_buffering_path = (gchar*)file_path;
+ LOGD("temp file path: %s\n", player->http_file_buffering_path);
}
MMPLAYER_FLEAVE();
return result;
@@ -13989,7 +13989,7 @@ const char *padname, const GList *templlist)
1.0,
player->ini.http_buffering_limit,
type,
- player->http_file_buffer_path,
+ player->http_file_buffering_path,
(guint64)dur_bytes);
}
}
diff --git a/src/include/mm_player.h b/src/include/mm_player.h
index 3b77e98..28a5b47 100644
--- a/src/include/mm_player.h
+++ b/src/include/mm_player.h
@@ -2327,7 +2327,7 @@ int mm_player_set_media_stream_dynamic_resolution(MMHandleType player, bool drc)
int mm_player_release_video_stream_bo(MMHandleType player, void* bo);
/**
* This function is to set mused temp file path.
*
* @param player [in] handle of player
* @param file_path [in] file path
@@ -2336,7 +2336,7 @@ int mm_player_release_video_stream_bo(MMHandleType player, void* bo);
* @see
* @remark None
*/
-int mm_player_set_temp_file_path(MMHandleType player, const char *file_path);
+int mm_player_set_file_buffering_path(MMHandleType player, const char *file_path);
/**
@}
@@ -2327,7 +2327,7 @@ int mm_player_set_media_stream_dynamic_resolution(MMHandleType player, bool drc)
int mm_player_release_video_stream_bo(MMHandleType player, void* bo);
/**
- * This function is to set mused temp file path.
+ * This function is to set http file buffering path
*
* @param player [in] handle of player